==> haskell-aeson-compat-0.3.6-15-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.6
id: aeson-compat-0.3.6-LrzwUZQrWE9KpdVy7fkGIy
key: aeson-compat-0.3.6-LrzwUZQrWE9KpdVy7fkGIy
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Aeson.Compat
hidden-modules: Data.Aeson.Compat.Time
abi: 0f87f58608f3bc4e5908261d65104bd7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-compat-0.3.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-compat-0.3.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/aeson-compat-0.3.6
hs-libraries: HSaeson-compat-0.3.6-LrzwUZQrWE9KpdVy7fkGIy
depends:
    aeson-1.1.2.0-H03krkO26IxG3qbwGKHggZ
    attoparsec-0.13.1.0-8c6XBOrZgakIL7qfHejbmf base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF bytestring-0.10.8.1
    containers-0.5.7.1 exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    hashable-1.2.6.0-En2FSYN34Tp8YO8pqagtg1
    scientific-0.3.4.12-HGDD5CZlHOuAviiRjYU5iD
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.1-FgcR4Xf0VlEHD9HLxzq9WJ time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    unordered-containers-0.2.8.0-HozSxlbOa6oDZVsS46CFCU
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-aeson-compat-0.3.6-17-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-aeson-compat.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: aeson-compat
version: 0.3.6
id: aeson-compat-0.3.6-LdpqxvC9OgL9VImZ5qaD2f
key: aeson-compat-0.3.6-LdpqxvC9OgL9VImZ5qaD2f
license: BSD3
maintainer: Oleg Grenrus <oleg.grenrus@iki.fi>
homepage: https://github.com/phadej/aeson-compat#readme
synopsis: Compatibility layer for aeson
description:
    Compatibility layer for @aeson@
category: Web
author: Oleg Grenrus <oleg.grenrus@iki.fi>
exposed: True
exposed-modules:
    Data.Aeson.Compat
hidden-modules: Data.Aeson.Compat.Time
abi: 996fb2bf87b4b97b04247e94e05e2cf3
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-compat-0.3.6
library-dirs: /usr/lib/ghc-8.0.1/site-local/aeson-compat-0.3.6
data-dir: /usr/share/arm-linux-ghc-8.0.1/aeson-compat-0.3.6
hs-libraries: HSaeson-compat-0.3.6-LdpqxvC9OgL9VImZ5qaD2f
depends:
    aeson-1.1.2.0-KxdCZ7gJzCsHXfqqwVMGzQ
    attoparsec-0.13.1.0-KaQFES0So1u93CSgT9OS1a base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF bytestring-0.10.8.1
    containers-0.5.7.1 exceptions-0.8.3-5cAKIsqc1DD7jaNW3zLxAN
    hashable-1.2.6.0-CKFo6Z8S7bXH0jokyKXcu0
    scientific-0.3.4.13-4xwcJxzSIhZ6kELOWf7cDt
    semigroups-0.18.3-8OeihxGDuPl3I5Jsa4Tvoj
    tagged-0.8.5-I7Gu0uzBLkQJCVUvdvwKKq
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v time-1.6.0.1
    time-locale-compat-0.1.1.3-1j5dGjxxtiTDuAsO86iSk0
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    vector-0.12.0.1-FyKxZ6HyOdr5RycjHR2p0f
haddock-interfaces: /usr/share/doc/haskell-aeson-compat/html/aeson-compat.haddock
haddock-html: /usr/share/doc/haskell-aeson-compat/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
